@@ -60,6 +60,9 @@ class SingleTarLookup:
         content = tarf.read(size)
         return content
 
+    def has_file(self, filename_in: str) -> bool:
+        return filename_in in self.index["files"]
+
     def close(self):
         if self.worker_id in self.filepointers:
             self.filepointers[self.worker_id].close()
@@ -150,7 +153,7 @@ def compress_files_to_tar(
 ):
     if tar_file.is_file():
         if verify:
-            # todo verify tar and files
+            assert verify_tar(tar_file, base_dir, rel_files), f"Verification failed for {tar_file}"
             return
         return
     # tar does not exist, create the tar
